@@ -8,8 +8,8 @@ def expo_weighted_cov(ret_data,w_lambda):
         weight[len(ret_data)-1-i]  = (1-w_lambda)*w_lambda**i
     weight = weight/sum(weight)
     ret_means = ret_data - ret_data.mean()
-    expo_w_cov = ret_means.T @ np.diag(weight) @ ret_means
-    return expo_w_cov.values
+    expo_w_cov = ret_means.T.values @ np.diag(weight) @ ret_means.values
+    return expo_w_cov
 
 # Pearson corr mtx + EW var vec
 def PS_corr_mtx_EW_var_vec(ret_data, w_lambda=0.97):
